@@ -4,10 +4,10 @@
 
 __author__  = "Sorin Sbarnea"
 __copyright__ = "Copyright 2010-2012, Sorin Sbarnea"
-__email__   = "sorindotsbarnea@gmail.com"
+__email__   = "sorin(dot)sbarnea(at)gmail.com"
 __status__  = "Development"
-__version__ = "0.0.14"
-__date__    = "2012-05-30"
+__version__ = "0.0.16"
+__date__    = "2012-10-04"
 
 __all__ = ['tee','colorer','unicode','execfile2','singleton','ansiterm']
 
